@@ -9,7 +9,8 @@ mod workflow_definition;
 mod workflow_instance;
 
 pub use common::{
-  Icon, Identifier, JobsStatus, Parameter, ParameterType, Step, StepMode, Store, WorkflowDuration,
+  Coordinates, Icon, Identifier, JobsStatus, Parameter, ParameterType, Step, StepMode, Store,
+  WorkflowDuration,
 };
 pub use credential::{Credential, CredentialContent};
 pub use job::Job;
